# CellCycleNet

![CellCycleNet Diagram](https://raw.githubusercontent.com/Noble-Lab/CellCycleNet/main/docs/img/CellCycleNet_diagram.png)

## Installation

**Option 1:** Install via pip: `pip install cellcyclenet`

**Option 2:** Install via conda or build the development conda environment: [see documentation](https://github.com/Noble-Lab/CellCycleNet/blob/main/docs/dev_env_setup.md)

## Running the included examples

1. After installation, download `example_data.zip` from [here](https://beliveau-shared.s3.us-east-2.amazonaws.com/cellcyclenet/data/example_data.zip).

2. Try running the included examples on these example files using the included example notebooks:

	1. [Example #1](https://github.com/Noble-Lab/CellCycleNet/blob/main/notebooks/01_prediction_demo.ipynb): Predict cell cycle stage from segmented DAPI images
	2. [Example #2](https://github.com/Noble-Lab/CellCycleNet/blob/main/notebooks/02_fine_tune_training_demo.ipynb): Fine tune pre-trained model with additional training
